pub trait Assignable<T> {
// Required method
fn from(value: T) -> Self;
}Expand description
Trait for types that can be used with the Binary::op_assign to assign
the result of the Binary operation to the left-hand operand.
See Async::assignable.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<'a, T, Fut: Future<Output = T> + 'a> Assignable<Fut> for LocalBoxFuture<'a, T>
impl<'a, T, Fut: Future<Output = T> + 'a> Assignable<Fut> for LocalBoxFuture<'a, T>
Sourcefn from(future: Fut) -> Self
fn from(future: Fut) -> Self
Wrap the given Future with LocalBoxFuture.